@@ -4,7 +4,7 @@ const { merge } = require('webpack-merge');
 const commonConfig = require('./webpack.config.common');
 
 const webpackConfig = {
-    mode: 'development'
+  mode: 'development',
 };
 
 module.exports = merge(commonConfig, webpackConfig);
